////////////////////////////////////////////////////////////////////////////////////
// Version history
////////////////////////////////////////////////////////////////////////////////////
// Date        | Vers.   | created               			| Author          | Remark
// dd.mm.yyyy  |         | with                  			|                 | 
// ---------------------------------------------------------------------------------
// 06.06.2018  | 0.01.0  | AS V4.3.3.196					| SIKO GmbH / ch  | alpha
// 28.06.2018  | 1.00.0  | AS V4.3.3.196					| SIKO GmbH / ch  | release
////////////////////////////////////////////////////////////////////////////////////

(* Function Block for SIKO AG24 *)
FUNCTION_BLOCK FB_SikoAg24

	(* Control Word *)
	DC_nControlWord.0:= bc00_Off1;
	DC_nControlWord.1:= bc01_Off2;
	DC_nControlWord.2:= bc02_Off3;
	DC_nControlWord.3:= bc03_IntermediateStop;
	DC_nControlWord.4:= bc04_StartTravelJob;
	DC_nControlWord.5:= bc05_AckError;
	DC_nControlWord.6:= bc06_InchingMode1;
	DC_nControlWord.7:= bc07_Inching2Pos;
	DC_nControlWord.8:= bc08_Inching2Neg;
	DC_nControlWord.9:= bc09_KeyEnable;
	DC_nControlWord.10:= bc10_MoveRelative;
	DC_nControlWord.11:= bc11;
	DC_nControlWord.12:= bc12;
	DC_nControlWord.13:= bc13;
	DC_nControlWord.14:= bc14;
	DC_nControlWord.15:= bc15_Cal;
	
	(* Target Value *)
	DC_nTargetValue := nTargetValue;
	
	(* Digital Outputs *)
	DC_nDigitalOutputsControl.0 := bcDigitalOutput1;

	(* Edge Detection *)
	fbR_TRIG1(CLK:= bcStartRead);
	vbOsrRead := fbR_TRIG1.Q;
	
	fbR_TRIG2(CLK:= bcStartWrite);
	vbOsrWrite := fbR_TRIG2.Q;
	
	fbR_TRIG3(CLK:= bcStartCopy);
	vbOsrCopy := fbR_TRIG3.Q;
	
	fbR_TRIG4(CLK:= bcStartReadDataObj);
	vbOsrReadDataObj:= fbR_TRIG4.Q;
	
	fbR_TRIG5(CLK:= bcStartWriteDataObj);
	vbOsrWriteDataObj:= fbR_TRIG5.Q;
	
	(* State Machines *)
	CASE vnRdState OF
		RD_STATE_WAIT_RTRIG: (* wait for rising edge at input bc_StartRead *)
			IF vbOsrRead AND (vnWrState = 0) AND (vnCopyState = 0) AND (vnRdDataObjState = 0) AND (vnWrDataObjState = 0) THEN
				IF (bsParameterValid = TRUE) THEN
					bsBusy := 1;
					bsError := 0;
					bsDone := 0;
					nStatus := 16#FFFF; (* bsBusy *)
					nErrorInfo := 0;
					vnRdState := 1;
					vnCounterRead := 0;
					nCounterRead := 0;
				ELSE
					bsBusy := 0;
					bsError := 1;
					bsDone := 0;
					nStatus := 50000; (* no data object loaded *)
					nErrorInfo := 0;
				END_IF;	
			END_IF;
		RD_STATE_INIT_EPL_SDO_READ: (* init EplSDORead *)
			vnCounterRead := vnCounterRead + 1;
			IF (vnCounterRead > 109) THEN
				(* no more parameters to read *)
				vnCounterRead := 0;
				nCounterRead := 0;
				vnRdState := RD_STATE_WAIT_RTRIG;
				bsBusy := 0;
				bsError := 0;
				bsDone := 1;
				nStatus := 0; (* no bsError *)
				nErrorInfo := 0;
			ELSE
				(* init EplSDORead *)
				CASE vnCounterRead OF
					1:  (* Service Interface Baud Rate *)
						fbEplSDORead.index := 16#2221;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_r);
					2:  (* Generic Mapping Parameter *)
						fbEplSDORead.index := 16#2222;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2222_GenMapParam_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2222_GenMapParam_r);
					3:  (* Peak Current Limit *)
						fbEplSDORead.index := 16#2241;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2241_PeakCurrentLimit_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2241_PeakCurrentLimit_r);
					4:  (* Peak Current Time *)
						fbEplSDORead.index := 16#2242;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2242_PeakCurrentTime_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2242_PeakCurrentTime_r);
					5:  (* Continuous Current *)
						fbEplSDORead.index := 16#2243;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2243_ContinuousCurrent_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2243_ContinuousCurrent_r);
					6:  (* Digital Output 1 Functionality *)
						fbEplSDORead.index := 16#2301;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2301_Do1Functionality_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2301_Do1Functionality_r);
					7:  (* Digital Output Functionalities State *)
						fbEplSDORead.index := 16#2302;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2302_DoFunctionalitiesState_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2302_DoFunctionalitiesState_r);
					8:  (* Digital Outputs Polarity *)
						fbEplSDORead.index := 16#2303;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2303_DoPolarity_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2303_DoPolarity_r);
					9:  (* Digital Input 1 Functionality *)
						fbEplSDORead.index := 16#2401;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2401_Di1Functionality_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2401_Di1Functionality_r);
					10:  (* Digital Input 2 Functionality *)
						fbEplSDORead.index := 16#2402;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2402_Di2Functionality_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2402_Di2Functionality_r);
					11:  (* Digital Input 3 Functionality *)
						fbEplSDORead.index := 16#2403;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2403_Di3Functionality_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2403_Di3Functionality_r);
					12:  (* Digital Input 4 Functionality *)
						fbEplSDORead.index := 16#2404;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2404_Di4Functionality_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2404_Di4Functionality_r);
					13:  (* Digital Input Functionalities State *)
						fbEplSDORead.index := 16#2405;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2405_DiFunctionalitiesState_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2405_DiFunctionalitiesState_r);
					14:  (* Digital Inputs Polarity *)
						fbEplSDORead.index := 16#2406;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2406_DiPolarity_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2406_DiPolarity_r);
					15:  (* Controller Parameter P *)
						fbEplSDORead.index := 16#2601;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2601_ControllerParameterP_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2601_ControllerParameterP_r);
					16:  (* Controller Parameter I *)
						fbEplSDORead.index := 16#2602;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2602_ControllerParameterI_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2602_ControllerParameterI_r);
					17:  (* Controller Parameter D *)
						fbEplSDORead.index := 16#2603;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2603_ControllerParameterD_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2603_ControllerParameterD_r);
					18:  (* A-Pos *)
						fbEplSDORead.index := 16#2604;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2604_APos_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2604_APos_r);
					19:  (* V-Pos *)
						fbEplSDORead.index := 16#2605;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2605_VPos_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2605_VPos_r);
					20:  (* D-Pos *)
						fbEplSDORead.index := 16#2606;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2606_DPos_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2606_DPos_r);
					21:  (* A-Rot *)
						fbEplSDORead.index := 16#2607;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2607_ARot_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2607_ARot_r);
					22:  (* A-Inch *)
						fbEplSDORead.index := 16#2608;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2608_AInch_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2608_AInch_r);
					23:  (* V-Inch *)
						fbEplSDORead.index := 16#2609;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2609_VInch_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2609_VInch_r);
					24:  (* Pos Window *)
						fbEplSDORead.index := 16#260A;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260A_PosWindow_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260A_PosWindow_r);
					25:  (* Gear Ratio Numerator *)
						fbEplSDORead.index := 16#260B;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260B_GearRatioNumerator_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260B_GearRatioNumerator_r);
					26:  (* Gear Ratio Denominator *)
						fbEplSDORead.index := 16#260C;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260C_GearRatioDenominator_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260C_GearRatioDenominator_r);
					27:  (* Spindle Pitch *)
						fbEplSDORead.index := 16#260D;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260D_SpindlePitch_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260D_SpindlePitch_r);
					28:  (* Calibration Value *)
						fbEplSDORead.index := 16#260E;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260E_CalibrationValue_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260E_CalibrationValue_r);
					29:  (* Software Limit 1 *)
						fbEplSDORead.index := 16#260F;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p260F_SoftwareLimit1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p260F_SoftwareLimit1_r);
					30:  (* Software Limit 2 *)
						fbEplSDORead.index := 16#2610;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2610_SoftwareLimit2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2610_SoftwareLimit2_r);
					31:  (* Delta Inch *)
						fbEplSDORead.index := 16#2611;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2611_DeltaInch_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2611_DeltaInch_r);
					32:  (* Sense of Rotation *)
						fbEplSDORead.index := 16#2612;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2612_SenseOfRotation_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2612_SenseOfRotation_r);
					33:  (* Pos Type *)
						fbEplSDORead.index := 16#2613;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2613_PosType_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2613_PosType_r);
					34:  (* Operating Mode *)
						fbEplSDORead.index := 16#2614;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2614_OperatingMode_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2614_OperatingMode_r);
					35:  (* Inching 2 Stop Mode *)
						fbEplSDORead.index := 16#2615;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2615_Inching2StopMode_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2615_Inching2StopMode_r);
					36:  (* Inpos Mode *)
						fbEplSDORead.index := 16#2616;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2616_InposMode_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2616_InposMode_r);
					37:  (* Loop Length *)
						fbEplSDORead.index := 16#2617;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2617_LoopLength_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2617_LoopLength_r);
					38:  (* Contouring Error Limit *)
						fbEplSDORead.index := 16#2618;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2618_ContouringErrorLimit_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2618_ContouringErrorLimit_r);
					39:  (* Inching 2 Offset *)
						fbEplSDORead.index := 16#261A;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p261A_Inching2Offset_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p261A_Inching2Offset_r);
					40:  (* Inching 2 Acceleration Type *)
						fbEplSDORead.index := 16#261B;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p261B_Inching2AccelerationType_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p261B_Inching2AccelerationType_r);
					41:  (* Offset Value *)
						fbEplSDORead.index := 16#261C;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p261C_OffsetValue_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p261C_OffsetValue_r);
					42:  (* Display Divisor *)
						fbEplSDORead.index := 16#2701;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2701_DisplayDivisor_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2701_DisplayDivisor_r);
					43:  (* Display Divisor Application *)
						fbEplSDORead.index := 16#2702;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2702_DisplayDivApplication_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2702_DisplayDivApplication_r);
					44:  (* Display Orientation *)
						fbEplSDORead.index := 16#2703;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2703_DisplayOrientation_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2703_DisplayOrientation_r);
					45:  (* Decimal Places *)
						fbEplSDORead.index := 16#2704;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2704_DecimalPlaces_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2704_DecimalPlaces_r);
					46:  (* Direction Indication Function *)
						fbEplSDORead.index := 16#2705;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2705_DirectionIndicationFunc_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2705_DirectionIndicationFunc_r);
					47:  (* Displayed Value 2nd Line *)
						fbEplSDORead.index := 16#2706;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2706_Display2ndLine_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2706_Display2ndLine_r);
					48:  (* Key Enable Time *)
						fbEplSDORead.index := 16#2707;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2707_KeyEnableTime_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2707_KeyEnableTime_r);
					49:  (* Key Function Enable *)
						fbEplSDORead.index := 16#2708;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2708_KeyFunctionEnable_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2708_KeyFunctionEnable_r);
					50:  (* PIN change *)
						fbEplSDORead.index := 16#2709;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2709_PinChange_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2709_PinChange_r);
					51:  (* Travel Against Load Trigger *)
						fbEplSDORead.index := 16#2801;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2801_TalTrigger_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2801_TalTrigger_r);
					52:  (* Travel Against Load Direction *)
						fbEplSDORead.index := 16#2802;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2802_TalDirection_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2802_TalDirection_r);
					53:  (* PCM Position 1 *)
						fbEplSDORead.index := 16#2922;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2922_PcmPosition1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2922_PcmPosition1_r);
					54:  (* PCM Position 2 *)
						fbEplSDORead.index := 16#2923;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2923_PcmPosition2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2923_PcmPosition2_r);
					55:  (* PCM Position 3 *)
						fbEplSDORead.index := 16#2924;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2924_PcmPosition3_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2924_PcmPosition3_r);
					56:  (* PCM Position 4 *)
						fbEplSDORead.index := 16#2925;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2925_PcmPosition4_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2925_PcmPosition4_r);
					57:  (* PCM Position 5 *)
						fbEplSDORead.index := 16#2926;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2926_PcmPosition5_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2926_PcmPosition5_r);
					58:  (* PCM Position 6 *)
						fbEplSDORead.index := 16#2927;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2927_PcmPosition6_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2927_PcmPosition6_r);
					59:  (* PCM Position 7 *)
						fbEplSDORead.index := 16#2928;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2928_PcmPosition7_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2928_PcmPosition7_r);
					60:  (* PCM Acceleration 1 *)
						fbEplSDORead.index := 16#2942;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2942_PcmAcceleration1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2942_PcmAcceleration1_r);
					61:  (* PCM Acceleration 2 *)
						fbEplSDORead.index := 16#2943;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2943_PcmAcceleration2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2943_PcmAcceleration2_r);
					62:  (* PCM Acceleration 3 *)
						fbEplSDORead.index := 16#2944;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2944_PcmAcceleration3_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2944_PcmAcceleration3_r);
					63:  (* PCM Acceleration 4 *)
						fbEplSDORead.index := 16#2945;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2945_PcmAcceleration4_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2945_PcmAcceleration4_r);
					64:  (* PCM Acceleration 5 *)
						fbEplSDORead.index := 16#2946;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2946_PcmAcceleration5_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2946_PcmAcceleration5_r);
					65:  (* PCM Acceleration 6 *)
						fbEplSDORead.index := 16#2947;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2947_PcmAcceleration6_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2947_PcmAcceleration6_r);
					66:  (* PCM Acceleration 7 *)
						fbEplSDORead.index := 16#2948;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2948_PcmAcceleration7_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2948_PcmAcceleration7_r);
					67:  (* PCM Velocitiy 1 *)
						fbEplSDORead.index := 16#2962;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2962_PcmVelocity1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2962_PcmVelocity1_r);
					68:  (* PCM Velocitiy 2 *)
						fbEplSDORead.index := 16#2963;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2963_PcmVelocity2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2963_PcmVelocity2_r);
					69:  (* PCM Velocitiy 3 *)
						fbEplSDORead.index := 16#2964;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2964_PcmVelocity3_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2964_PcmVelocity3_r);
					70:  (* PCM Velocitiy 4 *)
						fbEplSDORead.index := 16#2965;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2965_PcmVelocity4_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2965_PcmVelocity4_r);
					71:  (* PCM Velocitiy 5 *)
						fbEplSDORead.index := 16#2966;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2966_PcmVelocity5_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2966_PcmVelocity5_r);
					72:  (* PCM Velocitiy 6 *)
						fbEplSDORead.index := 16#2967;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2967_PcmVelocity6_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2967_PcmVelocity6_r);
					73:  (* PCM Velocitiy 7 *)
						fbEplSDORead.index := 16#2968;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2968_PcmVelocity7_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2968_PcmVelocity7_r);
					74:  (* PCM Deceleration 1 *)
						fbEplSDORead.index := 16#2982;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2982_PcmDeceleration1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2982_PcmDeceleration1_r);
					75:  (* PCM Deceleration 2 *)
						fbEplSDORead.index := 16#2983;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2983_PcmDeceleration2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2983_PcmDeceleration2_r);
					76:  (* PCM Deceleration 3 *)
						fbEplSDORead.index := 16#2984;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2984_PcmDeceleration3_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2984_PcmDeceleration3_r);
					77:  (* PCM Deceleration 4 *)
						fbEplSDORead.index := 16#2985;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2985_PcmDeceleration4_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2985_PcmDeceleration4_r);
					78:  (* PCM Deceleration 5 *)
						fbEplSDORead.index := 16#2986;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2986_PcmDeceleration5_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2986_PcmDeceleration5_r);
					79:  (* PCM Deceleration 6 *)
						fbEplSDORead.index := 16#2987;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2987_PcmDeceleration6_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2987_PcmDeceleration6_r);
					80:  (* PCM Deceleration 7 *)
						fbEplSDORead.index := 16#2988;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2988_PcmDeceleration7_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2988_PcmDeceleration7_r);
					81:  (* Output Stage Temperature *)
						fbEplSDORead.index := 16#2A01;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A01_OutputStageTemperature_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A01_OutputStageTemperature_r);
					82:  (* Voltage of Control *)
						fbEplSDORead.index := 16#2A02;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A02_VoltageOfControl_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A02_VoltageOfControl_r);
					83:  (* Voltage of Output Stage *)
						fbEplSDORead.index := 16#2A03;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A03_VoltageOfOutputStage_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A03_VoltageOfOutputStage_r);
					84:  (* Motor Current *)
						fbEplSDORead.index := 16#2A05;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A05_MotorCurrent_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A05_MotorCurrent_r);
					85:  (* Actual Position *)
						fbEplSDORead.index := 16#2A06;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A06_ActualPosition_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A06_ActualPosition_r);
					86:  (* Actual Rotational Speed *)
						fbEplSDORead.index := 16#2A07;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A07_ActualRotationalSpeed_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A07_ActualRotationalSpeed_r);
					87:  (* Serial Number *)
						fbEplSDORead.index := 16#2A08;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A08_SerialNumber_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A08_SerialNumber_r);
					88:  (* Production Date *)
						fbEplSDORead.index := 16#2A09;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A09_ProductionDate_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A09_ProductionDate_r);
					89:  (* SW Motor Controller *)
						fbEplSDORead.index := 16#2A0A;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0A_SwMotorController_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0A_SwMotorController_r);
					90:  (* Gear Reduction *)
						fbEplSDORead.index := 16#2A0B;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0B_GearReduction_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0B_GearReduction_r);
					91:  (* System Status Word *)
						fbEplSDORead.index := 16#2A0C;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0C_SystemStatusWord_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0C_SystemStatusWord_r);
					92:  (* Encoder Resolution *)
						fbEplSDORead.index := 16#2A0D;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0D_EncoderResolution_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0D_EncoderResolution_r);
					93:  (* Device ID *)
						fbEplSDORead.index := 16#2A0E;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0E_DeviceId_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0E_DeviceId_r);
					94:  (* Virtual Motor Temperature *)
						fbEplSDORead.index := 16#2A0F;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A0F_VirtualMotorTemperature_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A0F_VirtualMotorTemperature_r);
					95:  (* Overload *)
						fbEplSDORead.index := 16#2A10;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A10_OutputStageOverload_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A10_OutputStageOverload_r);
					96:  (* Actual Contouring Error *)
						fbEplSDORead.index := 16#2A11;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2A11_ActualContouringError_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2A11_ActualContouringError_r);
					97:  (* Number of Errors *)
						fbEplSDORead.index := 16#2B01;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B01_NumberOfErrors_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B01_NumberOfErrors_r);
					98:  (* Error Number 1 *)
						fbEplSDORead.index := 16#2B02;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B02_ErrorNumber1_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B02_ErrorNumber1_r);
					99:  (* Error Number 2 *)
						fbEplSDORead.index := 16#2B03;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B03_ErrorNumber2_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B03_ErrorNumber2_r);
					100:  (* Error Number 3 *)
						fbEplSDORead.index := 16#2B04;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B04_ErrorNumber3_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B04_ErrorNumber3_r);
					101:  (* Error Number 4 *)
						fbEplSDORead.index := 16#2B05;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B05_ErrorNumber4_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B05_ErrorNumber4_r);
					102:  (* Error Number 5 *)
						fbEplSDORead.index := 16#2B06;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B06_ErrorNumber5_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B06_ErrorNumber5_r);
					103:  (* Error Number 6 *)
						fbEplSDORead.index := 16#2B07;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B07_ErrorNumber6_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B07_ErrorNumber6_r);
					104:  (* Error Number 7 *)
						fbEplSDORead.index := 16#2B08;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B08_ErrorNumber7_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B08_ErrorNumber7_r);
					105:  (* Error Number 8 *)
						fbEplSDORead.index := 16#2B09;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B09_ErrorNumber8_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B09_ErrorNumber8_r);
					106:  (* Error Number 9 *)
						fbEplSDORead.index := 16#2B0A;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B0A_ErrorNumber9_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B0A_ErrorNumber9_r);
					107:  (* Error Number 10 *)
						fbEplSDORead.index := 16#2B0B;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B0B_ErrorNumber10_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B0B_ErrorNumber10_r);
					108:  (* Configuration *)
						fbEplSDORead.index := 16#2B21;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2B21_Configuration_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2B21_Configuration_r);
					109:  (* S-Command *)
						fbEplSDORead.index := 16#2C01;
						fbEplSDORead.subindex := 0;
						fbEplSDORead.pData := ADR(DC_pstParameterAg24.p2C01_Scommand_r);
						fbEplSDORead.datalen := SIZEOF(DC_pstParameterAg24.p2C01_Scommand_r);
				END_CASE;
				vnRdState := RD_STATE_EXEC_EPL_SDO_READ;
			END_IF;	
			nCounterRead := vnCounterRead;
		RD_STATE_EXEC_EPL_SDO_READ: (* execute EplSDORead *)
			fbEplSDORead(enable := TRUE, node:=DC_nNodeId, pDevice:= ADR(DC_sDevicename));
			IF fbEplSDORead.status <> 16#FFFF THEN
				IF fbEplSDORead.status = 0 THEN
					(* read success *)
					vnRdState := RD_STATE_INIT_EPL_SDO_READ;
				ELSE
					(* read bsError *)
					nCounterRead := vnCounterRead;
					vnCounterRead := 0;
					vnRdState := RD_STATE_WAIT_RTRIG;
					bsDone:=FALSE;
					bsBusy:=FALSE;
					bsError:=TRUE;
					nStatus := fbEplSDORead.status;
					nErrorInfo := fbEplSDORead.errorinfo;
				END_IF;
			END_IF;
	END_CASE;
	
	CASE vnWrState OF
		WR_STATE_WAIT_RTRIG: (* wait for rising edge at input bc_StartWrite *)
			IF vbOsrWrite AND (vnRdState = 0) AND (vnCopyState = 0) AND (vnRdDataObjState = 0) AND (vnWrDataObjState = 0) THEN
				IF (bsParameterValid = TRUE) THEN
					vnCounterWrite := 0;
					nCounterWrite := 0;
					bsDone:=FALSE;
					bsBusy:=TRUE;
					bsError:=FALSE;
					nStatus := 16#FFFF; (* bsBusy *)
					nErrorInfo := 0;
					vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
				ELSE
					bsBusy := 0;
					bsError := 1;
					bsDone := 0;
					nStatus := 50000; (* no data object loaded *)
					nErrorInfo := 0;
				END_IF;	
			END_IF;	
		WR_STATE_INIT_EPL_SDO_WRITE: (* start fbEplSDOWrite *)
			vnCounterWrite := vnCounterWrite + 1;
			IF (vnCounterWrite > 80) THEN
				(* no more parameters to write *)
				vnCounterWrite := 0;
				nCounterWrite := 0;
				vnWrState := WR_STATE_WAIT_RTRIG;
				bsBusy := 0;
				bsError := 0;
				bsDone := 1;
				nStatus := 0; (* no bsError *)
				nErrorInfo := 0;
			ELSE
				(* init EplSDOWrite *)
				CASE vnCounterWrite OF
					1:  
						IF DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_r <> DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w	THEN
							fbEplSDOWrite.index := 16#2221;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					2:  
						IF DC_pstParameterAg24.p2222_GenMapParam_r <> DC_pstParameterAg24.p2222_GenMapParam_w	THEN
							fbEplSDOWrite.index := 16#2222;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2222_GenMapParam_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2222_GenMapParam_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					3:  
						IF DC_pstParameterAg24.p2241_PeakCurrentLimit_r <> DC_pstParameterAg24.p2241_PeakCurrentLimit_w	THEN
							fbEplSDOWrite.index := 16#2241;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2241_PeakCurrentLimit_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2241_PeakCurrentLimit_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					4:  
						IF DC_pstParameterAg24.p2242_PeakCurrentTime_r <> DC_pstParameterAg24.p2242_PeakCurrentTime_w	THEN
							fbEplSDOWrite.index := 16#2242;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2242_PeakCurrentTime_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2242_PeakCurrentTime_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					5:  
						IF DC_pstParameterAg24.p2243_ContinuousCurrent_r <> DC_pstParameterAg24.p2243_ContinuousCurrent_w	THEN
							fbEplSDOWrite.index := 16#2243;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2243_ContinuousCurrent_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2243_ContinuousCurrent_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					6:  
						IF DC_pstParameterAg24.p2301_Do1Functionality_r <> DC_pstParameterAg24.p2301_Do1Functionality_w	THEN
							fbEplSDOWrite.index := 16#2301;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2301_Do1Functionality_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2301_Do1Functionality_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					7:  
						IF DC_pstParameterAg24.p2303_DoPolarity_r <> DC_pstParameterAg24.p2303_DoPolarity_w	THEN
							fbEplSDOWrite.index := 16#2303;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2303_DoPolarity_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2303_DoPolarity_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					8:  
						IF DC_pstParameterAg24.p2401_Di1Functionality_r <> DC_pstParameterAg24.p2401_Di1Functionality_w	THEN
							fbEplSDOWrite.index := 16#2401;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2401_Di1Functionality_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2401_Di1Functionality_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					9:  
						IF DC_pstParameterAg24.p2402_Di2Functionality_r <> DC_pstParameterAg24.p2402_Di2Functionality_w	THEN
							fbEplSDOWrite.index := 16#2402;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2402_Di2Functionality_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2402_Di2Functionality_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					10:  
						IF DC_pstParameterAg24.p2403_Di3Functionality_r <> DC_pstParameterAg24.p2403_Di3Functionality_w	THEN
							fbEplSDOWrite.index := 16#2403;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2403_Di3Functionality_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2403_Di3Functionality_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					11:  
						IF DC_pstParameterAg24.p2404_Di4Functionality_r <> DC_pstParameterAg24.p2404_Di4Functionality_w	THEN
							fbEplSDOWrite.index := 16#2404;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2404_Di4Functionality_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2404_Di4Functionality_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					12:  
						IF DC_pstParameterAg24.p2406_DiPolarity_r <> DC_pstParameterAg24.p2406_DiPolarity_w	THEN
							fbEplSDOWrite.index := 16#2406;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2406_DiPolarity_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2406_DiPolarity_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					13:  
						IF DC_pstParameterAg24.p2601_ControllerParameterP_r <> DC_pstParameterAg24.p2601_ControllerParameterP_w	THEN
							fbEplSDOWrite.index := 16#2601;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2601_ControllerParameterP_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2601_ControllerParameterP_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					14:  
						IF DC_pstParameterAg24.p2602_ControllerParameterI_r <> DC_pstParameterAg24.p2602_ControllerParameterI_w	THEN
							fbEplSDOWrite.index := 16#2602;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2602_ControllerParameterI_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2602_ControllerParameterI_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					15:  
						IF DC_pstParameterAg24.p2603_ControllerParameterD_r <> DC_pstParameterAg24.p2603_ControllerParameterD_w	THEN
							fbEplSDOWrite.index := 16#2603;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2603_ControllerParameterD_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2603_ControllerParameterD_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					16:  
						IF DC_pstParameterAg24.p2604_APos_r <> DC_pstParameterAg24.p2604_APos_w	THEN
							fbEplSDOWrite.index := 16#2604;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2604_APos_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2604_APos_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					17:  
						IF DC_pstParameterAg24.p2605_VPos_r <> DC_pstParameterAg24.p2605_VPos_w	THEN
							fbEplSDOWrite.index := 16#2605;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2605_VPos_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2605_VPos_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					18:  
						IF DC_pstParameterAg24.p2606_DPos_r <> DC_pstParameterAg24.p2606_DPos_w	THEN
							fbEplSDOWrite.index := 16#2606;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2606_DPos_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2606_DPos_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					19:  
						IF DC_pstParameterAg24.p2607_ARot_r <> DC_pstParameterAg24.p2607_ARot_w	THEN
							fbEplSDOWrite.index := 16#2607;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2607_ARot_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2607_ARot_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					20:  
						IF DC_pstParameterAg24.p2608_AInch_r <> DC_pstParameterAg24.p2608_AInch_w	THEN
							fbEplSDOWrite.index := 16#2608;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2608_AInch_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2608_AInch_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					21:  
						IF DC_pstParameterAg24.p2609_VInch_r <> DC_pstParameterAg24.p2609_VInch_w	THEN
							fbEplSDOWrite.index := 16#2609;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2609_VInch_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2609_VInch_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					22:  
						IF DC_pstParameterAg24.p260A_PosWindow_r <> DC_pstParameterAg24.p260A_PosWindow_w	THEN
							fbEplSDOWrite.index := 16#260A;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260A_PosWindow_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260A_PosWindow_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					23:  
						IF DC_pstParameterAg24.p260B_GearRatioNumerator_r <> DC_pstParameterAg24.p260B_GearRatioNumerator_w	THEN
							fbEplSDOWrite.index := 16#260B;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260B_GearRatioNumerator_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260B_GearRatioNumerator_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					24:  
						IF DC_pstParameterAg24.p260C_GearRatioDenominator_r <> DC_pstParameterAg24.p260C_GearRatioDenominator_w	THEN
							fbEplSDOWrite.index := 16#260C;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260C_GearRatioDenominator_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260C_GearRatioDenominator_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					25:  
						IF DC_pstParameterAg24.p260D_SpindlePitch_r <> DC_pstParameterAg24.p260D_SpindlePitch_w	THEN
							fbEplSDOWrite.index := 16#260D;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260D_SpindlePitch_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260D_SpindlePitch_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					26:  
						IF DC_pstParameterAg24.p260E_CalibrationValue_r <> DC_pstParameterAg24.p260E_CalibrationValue_w	THEN
							fbEplSDOWrite.index := 16#260E;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260E_CalibrationValue_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260E_CalibrationValue_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					27:  
						IF DC_pstParameterAg24.p260F_SoftwareLimit1_r <> DC_pstParameterAg24.p260F_SoftwareLimit1_w	THEN
							fbEplSDOWrite.index := 16#260F;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p260F_SoftwareLimit1_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p260F_SoftwareLimit1_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					28:  
						IF DC_pstParameterAg24.p2610_SoftwareLimit2_r <> DC_pstParameterAg24.p2610_SoftwareLimit2_w	THEN
							fbEplSDOWrite.index := 16#2610;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2610_SoftwareLimit2_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2610_SoftwareLimit2_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					29:  
						IF DC_pstParameterAg24.p2611_DeltaInch_r <> DC_pstParameterAg24.p2611_DeltaInch_w	THEN
							fbEplSDOWrite.index := 16#2611;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2611_DeltaInch_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2611_DeltaInch_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					30:  
						IF DC_pstParameterAg24.p2612_SenseOfRotation_r <> DC_pstParameterAg24.p2612_SenseOfRotation_w	THEN
							fbEplSDOWrite.index := 16#2612;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2612_SenseOfRotation_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2612_SenseOfRotation_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					31:  
						IF DC_pstParameterAg24.p2613_PosType_r <> DC_pstParameterAg24.p2613_PosType_w	THEN
							fbEplSDOWrite.index := 16#2613;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2613_PosType_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2613_PosType_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					32:  
						IF DC_pstParameterAg24.p2614_OperatingMode_r <> DC_pstParameterAg24.p2614_OperatingMode_w	THEN
							fbEplSDOWrite.index := 16#2614;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2614_OperatingMode_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2614_OperatingMode_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					33:  
						IF DC_pstParameterAg24.p2615_Inching2StopMode_r <> DC_pstParameterAg24.p2615_Inching2StopMode_w	THEN
							fbEplSDOWrite.index := 16#2615;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2615_Inching2StopMode_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2615_Inching2StopMode_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					34:  
						IF DC_pstParameterAg24.p2616_InposMode_r <> DC_pstParameterAg24.p2616_InposMode_w	THEN
							fbEplSDOWrite.index := 16#2616;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2616_InposMode_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2616_InposMode_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					35:  
						IF DC_pstParameterAg24.p2617_LoopLength_r <> DC_pstParameterAg24.p2617_LoopLength_w	THEN
							fbEplSDOWrite.index := 16#2617;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2617_LoopLength_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2617_LoopLength_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					36:  
						IF DC_pstParameterAg24.p2618_ContouringErrorLimit_r <> DC_pstParameterAg24.p2618_ContouringErrorLimit_w	THEN
							fbEplSDOWrite.index := 16#2618;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2618_ContouringErrorLimit_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2618_ContouringErrorLimit_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					37:  
						IF DC_pstParameterAg24.p261A_Inching2Offset_r <> DC_pstParameterAg24.p261A_Inching2Offset_w	THEN
							fbEplSDOWrite.index := 16#261A;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p261A_Inching2Offset_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p261A_Inching2Offset_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					38:  
						IF DC_pstParameterAg24.p261B_Inching2AccelerationType_r <> DC_pstParameterAg24.p261B_Inching2AccelerationType_w	THEN
							fbEplSDOWrite.index := 16#261B;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p261B_Inching2AccelerationType_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p261B_Inching2AccelerationType_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					39:  
						IF DC_pstParameterAg24.p261C_OffsetValue_r <> DC_pstParameterAg24.p261C_OffsetValue_w	THEN
							fbEplSDOWrite.index := 16#261C;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p261C_OffsetValue_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p261C_OffsetValue_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					40:  
						IF DC_pstParameterAg24.p2701_DisplayDivisor_r <> DC_pstParameterAg24.p2701_DisplayDivisor_w	THEN
							fbEplSDOWrite.index := 16#2701;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2701_DisplayDivisor_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2701_DisplayDivisor_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					41:  
						IF DC_pstParameterAg24.p2702_DisplayDivApplication_r <> DC_pstParameterAg24.p2702_DisplayDivApplication_w	THEN
							fbEplSDOWrite.index := 16#2702;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2702_DisplayDivApplication_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2702_DisplayDivApplication_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					42:  
						IF DC_pstParameterAg24.p2703_DisplayOrientation_r <> DC_pstParameterAg24.p2703_DisplayOrientation_w	THEN
							fbEplSDOWrite.index := 16#2703;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2703_DisplayOrientation_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2703_DisplayOrientation_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					43:  
						IF DC_pstParameterAg24.p2704_DecimalPlaces_r <> DC_pstParameterAg24.p2704_DecimalPlaces_w	THEN
							fbEplSDOWrite.index := 16#2704;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2704_DecimalPlaces_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2704_DecimalPlaces_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					44:  
						IF DC_pstParameterAg24.p2705_DirectionIndicationFunc_r <> DC_pstParameterAg24.p2705_DirectionIndicationFunc_w	THEN
							fbEplSDOWrite.index := 16#2705;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2705_DirectionIndicationFunc_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2705_DirectionIndicationFunc_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					45:  
						IF DC_pstParameterAg24.p2706_Display2ndLine_r <> DC_pstParameterAg24.p2706_Display2ndLine_w	THEN
							fbEplSDOWrite.index := 16#2706;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2706_Display2ndLine_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2706_Display2ndLine_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					46:  
						IF DC_pstParameterAg24.p2707_KeyEnableTime_r <> DC_pstParameterAg24.p2707_KeyEnableTime_w	THEN
							fbEplSDOWrite.index := 16#2707;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2707_KeyEnableTime_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2707_KeyEnableTime_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					47:  
						IF DC_pstParameterAg24.p2708_KeyFunctionEnable_r <> DC_pstParameterAg24.p2708_KeyFunctionEnable_w	THEN
							fbEplSDOWrite.index := 16#2708;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2708_KeyFunctionEnable_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2708_KeyFunctionEnable_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					48:  
						IF DC_pstParameterAg24.p2709_PinChange_r <> DC_pstParameterAg24.p2709_PinChange_w	THEN
							fbEplSDOWrite.index := 16#2709;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2709_PinChange_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2709_PinChange_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					49:  
						IF DC_pstParameterAg24.p2801_TalTrigger_r <> DC_pstParameterAg24.p2801_TalTrigger_w	THEN
							fbEplSDOWrite.index := 16#2801;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2801_TalTrigger_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2801_TalTrigger_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					50:  
						IF DC_pstParameterAg24.p2802_TalDirection_r <> DC_pstParameterAg24.p2802_TalDirection_w	THEN
							fbEplSDOWrite.index := 16#2802;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2802_TalDirection_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2802_TalDirection_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					51:  
						IF DC_pstParameterAg24.p2922_PcmPosition1_r <> DC_pstParameterAg24.p2922_PcmPosition1_w	THEN
							fbEplSDOWrite.index := 16#2922;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2922_PcmPosition1_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2922_PcmPosition1_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					52:  
						IF DC_pstParameterAg24.p2923_PcmPosition2_r <> DC_pstParameterAg24.p2923_PcmPosition2_w	THEN
							fbEplSDOWrite.index := 16#2923;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2923_PcmPosition2_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2923_PcmPosition2_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					53:  
						IF DC_pstParameterAg24.p2924_PcmPosition3_r <> DC_pstParameterAg24.p2924_PcmPosition3_w	THEN
							fbEplSDOWrite.index := 16#2924;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2924_PcmPosition3_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2924_PcmPosition3_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					54:  
						IF DC_pstParameterAg24.p2925_PcmPosition4_r <> DC_pstParameterAg24.p2925_PcmPosition4_w	THEN
							fbEplSDOWrite.index := 16#2925;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2925_PcmPosition4_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2925_PcmPosition4_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					55:  
						IF DC_pstParameterAg24.p2926_PcmPosition5_r <> DC_pstParameterAg24.p2926_PcmPosition5_w	THEN
							fbEplSDOWrite.index := 16#2926;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2926_PcmPosition5_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2926_PcmPosition5_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					56:  
						IF DC_pstParameterAg24.p2927_PcmPosition6_r <> DC_pstParameterAg24.p2927_PcmPosition6_w	THEN
							fbEplSDOWrite.index := 16#2927;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2927_PcmPosition6_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2927_PcmPosition6_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					57:  
						IF DC_pstParameterAg24.p2928_PcmPosition7_r <> DC_pstParameterAg24.p2928_PcmPosition7_w	THEN
							fbEplSDOWrite.index := 16#2928;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2928_PcmPosition7_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2928_PcmPosition7_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					58:  
						IF DC_pstParameterAg24.p2942_PcmAcceleration1_r <> DC_pstParameterAg24.p2942_PcmAcceleration1_w	THEN
							fbEplSDOWrite.index := 16#2942;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2942_PcmAcceleration1_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2942_PcmAcceleration1_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					59:  
						IF DC_pstParameterAg24.p2943_PcmAcceleration2_r <> DC_pstParameterAg24.p2943_PcmAcceleration2_w	THEN
							fbEplSDOWrite.index := 16#2943;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2943_PcmAcceleration2_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2943_PcmAcceleration2_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					60:  
						IF DC_pstParameterAg24.p2944_PcmAcceleration3_r <> DC_pstParameterAg24.p2944_PcmAcceleration3_w	THEN
							fbEplSDOWrite.index := 16#2944;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2944_PcmAcceleration3_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2944_PcmAcceleration3_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					61:  
						IF DC_pstParameterAg24.p2945_PcmAcceleration4_r <> DC_pstParameterAg24.p2945_PcmAcceleration4_w	THEN
							fbEplSDOWrite.index := 16#2945;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2945_PcmAcceleration4_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2945_PcmAcceleration4_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					62:  
						IF DC_pstParameterAg24.p2946_PcmAcceleration5_r <> DC_pstParameterAg24.p2946_PcmAcceleration5_w	THEN
							fbEplSDOWrite.index := 16#2946;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2946_PcmAcceleration5_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2946_PcmAcceleration5_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					63:  
						IF DC_pstParameterAg24.p2947_PcmAcceleration6_r <> DC_pstParameterAg24.p2947_PcmAcceleration6_w	THEN
							fbEplSDOWrite.index := 16#2947;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2947_PcmAcceleration6_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2947_PcmAcceleration6_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					64:  
						IF DC_pstParameterAg24.p2948_PcmAcceleration7_r <> DC_pstParameterAg24.p2948_PcmAcceleration7_w	THEN
							fbEplSDOWrite.index := 16#2948;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2948_PcmAcceleration7_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2948_PcmAcceleration7_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					65:  
						IF DC_pstParameterAg24.p2962_PcmVelocity1_r <> DC_pstParameterAg24.p2962_PcmVelocity1_w	THEN
							fbEplSDOWrite.index := 16#2962;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2962_PcmVelocity1_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2962_PcmVelocity1_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					66:  
						IF DC_pstParameterAg24.p2963_PcmVelocity2_r <> DC_pstParameterAg24.p2963_PcmVelocity2_w	THEN
							fbEplSDOWrite.index := 16#2963;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2963_PcmVelocity2_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2963_PcmVelocity2_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					67:  
						IF DC_pstParameterAg24.p2964_PcmVelocity3_r <> DC_pstParameterAg24.p2964_PcmVelocity3_w	THEN
							fbEplSDOWrite.index := 16#2964;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2964_PcmVelocity3_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2964_PcmVelocity3_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					68:  
						IF DC_pstParameterAg24.p2965_PcmVelocity4_r <> DC_pstParameterAg24.p2965_PcmVelocity4_w	THEN
							fbEplSDOWrite.index := 16#2965;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2965_PcmVelocity4_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2965_PcmVelocity4_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					69:  
						IF DC_pstParameterAg24.p2966_PcmVelocity5_r <> DC_pstParameterAg24.p2966_PcmVelocity5_w	THEN
							fbEplSDOWrite.index := 16#2966;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2966_PcmVelocity5_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2966_PcmVelocity5_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					70:  
						IF DC_pstParameterAg24.p2967_PcmVelocity6_r <> DC_pstParameterAg24.p2967_PcmVelocity6_w	THEN
							fbEplSDOWrite.index := 16#2967;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2967_PcmVelocity6_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2967_PcmVelocity6_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					71:  
						IF DC_pstParameterAg24.p2968_PcmVelocity7_r <> DC_pstParameterAg24.p2968_PcmVelocity7_w	THEN
							fbEplSDOWrite.index := 16#2968;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2968_PcmVelocity7_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2968_PcmVelocity7_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					72:  
						IF DC_pstParameterAg24.p2982_PcmDeceleration1_r <> DC_pstParameterAg24.p2982_PcmDeceleration1_w	THEN
							fbEplSDOWrite.index := 16#2982;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2982_PcmDeceleration1_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2982_PcmDeceleration1_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					73:  
						IF DC_pstParameterAg24.p2983_PcmDeceleration2_r <> DC_pstParameterAg24.p2983_PcmDeceleration2_w	THEN
							fbEplSDOWrite.index := 16#2983;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2983_PcmDeceleration2_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2983_PcmDeceleration2_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					74:  
						IF DC_pstParameterAg24.p2984_PcmDeceleration3_r <> DC_pstParameterAg24.p2984_PcmDeceleration3_w	THEN
							fbEplSDOWrite.index := 16#2984;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2984_PcmDeceleration3_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2984_PcmDeceleration3_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					75:  
						IF DC_pstParameterAg24.p2985_PcmDeceleration4_r <> DC_pstParameterAg24.p2985_PcmDeceleration4_w	THEN
							fbEplSDOWrite.index := 16#2985;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2985_PcmDeceleration4_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2985_PcmDeceleration4_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					76:  
						IF DC_pstParameterAg24.p2986_PcmDeceleration5_r <> DC_pstParameterAg24.p2986_PcmDeceleration5_w	THEN
							fbEplSDOWrite.index := 16#2986;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2986_PcmDeceleration5_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2986_PcmDeceleration5_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					77:  
						IF DC_pstParameterAg24.p2987_PcmDeceleration6_r <> DC_pstParameterAg24.p2987_PcmDeceleration6_w	THEN
							fbEplSDOWrite.index := 16#2987;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2987_PcmDeceleration6_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2987_PcmDeceleration6_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					78:  
						IF DC_pstParameterAg24.p2988_PcmDeceleration7_r <> DC_pstParameterAg24.p2988_PcmDeceleration7_w	THEN
							fbEplSDOWrite.index := 16#2988;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2988_PcmDeceleration7_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2988_PcmDeceleration7_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					79:  
						IF DC_pstParameterAg24.p2B21_Configuration_r <> DC_pstParameterAg24.p2B21_Configuration_w	THEN
							fbEplSDOWrite.index := 16#2B21;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2B21_Configuration_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2B21_Configuration_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
					80:  
						IF DC_pstParameterAg24.p2C01_Scommand_r <> DC_pstParameterAg24.p2C01_Scommand_w	THEN
							fbEplSDOWrite.index := 16#2C01;
							fbEplSDOWrite.subindex := 0;
							fbEplSDOWrite.pData := ADR(DC_pstParameterAg24.p2C01_Scommand_w);
							fbEplSDOWrite.datalen := SIZEOF(DC_pstParameterAg24.p2C01_Scommand_w);
							vnWrState := WR_STATE_EXEC_EPL_SDO_WRITE;
						ELSE
							vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
						END_IF;
				END_CASE;
			END_IF;
			nCounterWrite := vnCounterWrite;
		WR_STATE_EXEC_EPL_SDO_WRITE: (* execute EplSDOWrite *)
			fbEplSDOWrite(enable:=TRUE, node:= DC_nNodeId, pDevice:= ADR(DC_sDevicename));
			IF (fbEplSDOWrite.status <> 16#FFFF) THEN
				IF fbEplSDOWrite.status = 0 THEN
					(* write success *)
					vnWrState := WR_STATE_INIT_EPL_SDO_WRITE;
					CASE vnCounterWrite OF
						1:  
							DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_r := DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w;
						2:  
							DC_pstParameterAg24.p2222_GenMapParam_r := DC_pstParameterAg24.p2222_GenMapParam_w;
						3:  
							DC_pstParameterAg24.p2241_PeakCurrentLimit_r := DC_pstParameterAg24.p2241_PeakCurrentLimit_w;
						4:  
							DC_pstParameterAg24.p2242_PeakCurrentTime_r := DC_pstParameterAg24.p2242_PeakCurrentTime_w;
						5:  
							DC_pstParameterAg24.p2243_ContinuousCurrent_r := DC_pstParameterAg24.p2243_ContinuousCurrent_w;
						6:  
							DC_pstParameterAg24.p2301_Do1Functionality_r := DC_pstParameterAg24.p2301_Do1Functionality_w;
						7:  
							DC_pstParameterAg24.p2303_DoPolarity_r := DC_pstParameterAg24.p2303_DoPolarity_w;
						8:  
							DC_pstParameterAg24.p2401_Di1Functionality_r := DC_pstParameterAg24.p2401_Di1Functionality_w;
						9:  
							DC_pstParameterAg24.p2402_Di2Functionality_r := DC_pstParameterAg24.p2402_Di2Functionality_w;
						10:  
							DC_pstParameterAg24.p2403_Di3Functionality_r := DC_pstParameterAg24.p2403_Di3Functionality_w;
						11:  
							DC_pstParameterAg24.p2404_Di4Functionality_r := DC_pstParameterAg24.p2404_Di4Functionality_w;
						12:  
							DC_pstParameterAg24.p2406_DiPolarity_r := DC_pstParameterAg24.p2406_DiPolarity_w;
						13:  
							DC_pstParameterAg24.p2601_ControllerParameterP_r := DC_pstParameterAg24.p2601_ControllerParameterP_w;
						14:  
							DC_pstParameterAg24.p2602_ControllerParameterI_r := DC_pstParameterAg24.p2602_ControllerParameterI_w;
						15:  
							DC_pstParameterAg24.p2603_ControllerParameterD_r := DC_pstParameterAg24.p2603_ControllerParameterD_w;
						16:  
							DC_pstParameterAg24.p2604_APos_r := DC_pstParameterAg24.p2604_APos_w;
						17:  
							DC_pstParameterAg24.p2605_VPos_r := DC_pstParameterAg24.p2605_VPos_w;
						18:  
							DC_pstParameterAg24.p2606_DPos_r := DC_pstParameterAg24.p2606_DPos_w;
						19:  
							DC_pstParameterAg24.p2607_ARot_r := DC_pstParameterAg24.p2607_ARot_w;
						20:  
							DC_pstParameterAg24.p2608_AInch_r := DC_pstParameterAg24.p2608_AInch_w;
						21:  
							DC_pstParameterAg24.p2609_VInch_r := DC_pstParameterAg24.p2609_VInch_w;
						22:  
							DC_pstParameterAg24.p260A_PosWindow_r := DC_pstParameterAg24.p260A_PosWindow_w;
						23:  
							DC_pstParameterAg24.p260B_GearRatioNumerator_r := DC_pstParameterAg24.p260B_GearRatioNumerator_w;
						24:  
							DC_pstParameterAg24.p260C_GearRatioDenominator_r := DC_pstParameterAg24.p260C_GearRatioDenominator_w;
						25:  
							DC_pstParameterAg24.p260D_SpindlePitch_r := DC_pstParameterAg24.p260D_SpindlePitch_w;
						26:  
							DC_pstParameterAg24.p260E_CalibrationValue_r := DC_pstParameterAg24.p260E_CalibrationValue_w;
						27:  
							DC_pstParameterAg24.p260F_SoftwareLimit1_r := DC_pstParameterAg24.p260F_SoftwareLimit1_w;
						28:  
							DC_pstParameterAg24.p2610_SoftwareLimit2_r := DC_pstParameterAg24.p2610_SoftwareLimit2_w;
						29:  
							DC_pstParameterAg24.p2611_DeltaInch_r := DC_pstParameterAg24.p2611_DeltaInch_w;
						30:  
							DC_pstParameterAg24.p2612_SenseOfRotation_r := DC_pstParameterAg24.p2612_SenseOfRotation_w;
						31:  
							DC_pstParameterAg24.p2613_PosType_r := DC_pstParameterAg24.p2613_PosType_w;
						32:  
							DC_pstParameterAg24.p2614_OperatingMode_r := DC_pstParameterAg24.p2614_OperatingMode_w;
						33:  
							DC_pstParameterAg24.p2615_Inching2StopMode_r := DC_pstParameterAg24.p2615_Inching2StopMode_w;
						34:  
							DC_pstParameterAg24.p2616_InposMode_r := DC_pstParameterAg24.p2616_InposMode_w;
						35:  
							DC_pstParameterAg24.p2617_LoopLength_r := DC_pstParameterAg24.p2617_LoopLength_w;
						36:  
							DC_pstParameterAg24.p2618_ContouringErrorLimit_r := DC_pstParameterAg24.p2618_ContouringErrorLimit_w;
						37:  
							DC_pstParameterAg24.p261A_Inching2Offset_r := DC_pstParameterAg24.p261A_Inching2Offset_w;
						38:  
							DC_pstParameterAg24.p261B_Inching2AccelerationType_r := DC_pstParameterAg24.p261B_Inching2AccelerationType_w;
						39:  
							DC_pstParameterAg24.p261C_OffsetValue_r := DC_pstParameterAg24.p261C_OffsetValue_w;
						40:  
							DC_pstParameterAg24.p2701_DisplayDivisor_r := DC_pstParameterAg24.p2701_DisplayDivisor_w;
						41:  
							DC_pstParameterAg24.p2702_DisplayDivApplication_r := DC_pstParameterAg24.p2702_DisplayDivApplication_w;
						42:  
							DC_pstParameterAg24.p2703_DisplayOrientation_r := DC_pstParameterAg24.p2703_DisplayOrientation_w;
						43:  
							DC_pstParameterAg24.p2704_DecimalPlaces_r := DC_pstParameterAg24.p2704_DecimalPlaces_w;
						44:  
							DC_pstParameterAg24.p2705_DirectionIndicationFunc_r := DC_pstParameterAg24.p2705_DirectionIndicationFunc_w;
						45:  
							DC_pstParameterAg24.p2706_Display2ndLine_r := DC_pstParameterAg24.p2706_Display2ndLine_w;
						46:  
							DC_pstParameterAg24.p2707_KeyEnableTime_r := DC_pstParameterAg24.p2707_KeyEnableTime_w;
						47:  
							DC_pstParameterAg24.p2708_KeyFunctionEnable_r := DC_pstParameterAg24.p2708_KeyFunctionEnable_w;
						48:  
							DC_pstParameterAg24.p2709_PinChange_r := DC_pstParameterAg24.p2709_PinChange_w;
						49:  
							DC_pstParameterAg24.p2801_TalTrigger_r := DC_pstParameterAg24.p2801_TalTrigger_w;
						50:  
							DC_pstParameterAg24.p2802_TalDirection_r := DC_pstParameterAg24.p2802_TalDirection_w;
						51:  
							DC_pstParameterAg24.p2922_PcmPosition1_r := DC_pstParameterAg24.p2922_PcmPosition1_w;
						52:  
							DC_pstParameterAg24.p2923_PcmPosition2_r := DC_pstParameterAg24.p2923_PcmPosition2_w;
						53:  
							DC_pstParameterAg24.p2924_PcmPosition3_r := DC_pstParameterAg24.p2924_PcmPosition3_w;
						54:  
							DC_pstParameterAg24.p2925_PcmPosition4_r := DC_pstParameterAg24.p2925_PcmPosition4_w;
						55:  
							DC_pstParameterAg24.p2926_PcmPosition5_r := DC_pstParameterAg24.p2926_PcmPosition5_w;
						56:  
							DC_pstParameterAg24.p2927_PcmPosition6_r := DC_pstParameterAg24.p2927_PcmPosition6_w;
						57:  
							DC_pstParameterAg24.p2928_PcmPosition7_r := DC_pstParameterAg24.p2928_PcmPosition7_w;
						58:  
							DC_pstParameterAg24.p2942_PcmAcceleration1_r := DC_pstParameterAg24.p2942_PcmAcceleration1_w;
						59:  
							DC_pstParameterAg24.p2943_PcmAcceleration2_r := DC_pstParameterAg24.p2943_PcmAcceleration2_w;
						60:  
							DC_pstParameterAg24.p2944_PcmAcceleration3_r := DC_pstParameterAg24.p2944_PcmAcceleration3_w;
						61:  
							DC_pstParameterAg24.p2945_PcmAcceleration4_r := DC_pstParameterAg24.p2945_PcmAcceleration4_w;
						62:  
							DC_pstParameterAg24.p2946_PcmAcceleration5_r := DC_pstParameterAg24.p2946_PcmAcceleration5_w;
						63:  
							DC_pstParameterAg24.p2947_PcmAcceleration6_r := DC_pstParameterAg24.p2947_PcmAcceleration6_w;
						64:  
							DC_pstParameterAg24.p2948_PcmAcceleration7_r := DC_pstParameterAg24.p2948_PcmAcceleration7_w;
						65:  
							DC_pstParameterAg24.p2962_PcmVelocity1_r := DC_pstParameterAg24.p2962_PcmVelocity1_w;
						66:  
							DC_pstParameterAg24.p2963_PcmVelocity2_r := DC_pstParameterAg24.p2963_PcmVelocity2_w;
						67:  
							DC_pstParameterAg24.p2964_PcmVelocity3_r := DC_pstParameterAg24.p2964_PcmVelocity3_w;
						68:  
							DC_pstParameterAg24.p2965_PcmVelocity4_r := DC_pstParameterAg24.p2965_PcmVelocity4_w;
						69:  
							DC_pstParameterAg24.p2966_PcmVelocity5_r := DC_pstParameterAg24.p2966_PcmVelocity5_w;
						70:  
							DC_pstParameterAg24.p2967_PcmVelocity6_r := DC_pstParameterAg24.p2967_PcmVelocity6_w;
						71:  
							DC_pstParameterAg24.p2968_PcmVelocity7_r := DC_pstParameterAg24.p2968_PcmVelocity7_w;
						72:  
							DC_pstParameterAg24.p2982_PcmDeceleration1_r := DC_pstParameterAg24.p2982_PcmDeceleration1_w;
						73:  
							DC_pstParameterAg24.p2983_PcmDeceleration2_r := DC_pstParameterAg24.p2983_PcmDeceleration2_w;
						74:  
							DC_pstParameterAg24.p2984_PcmDeceleration3_r := DC_pstParameterAg24.p2984_PcmDeceleration3_w;
						75:  
							DC_pstParameterAg24.p2985_PcmDeceleration4_r := DC_pstParameterAg24.p2985_PcmDeceleration4_w;
						76:  
							DC_pstParameterAg24.p2986_PcmDeceleration5_r := DC_pstParameterAg24.p2986_PcmDeceleration5_w;
						77:  
							DC_pstParameterAg24.p2987_PcmDeceleration6_r := DC_pstParameterAg24.p2987_PcmDeceleration6_w;
						78:  
							DC_pstParameterAg24.p2988_PcmDeceleration7_r := DC_pstParameterAg24.p2988_PcmDeceleration7_w;
						79:  
							DC_pstParameterAg24.p2B21_Configuration_r := DC_pstParameterAg24.p2B21_Configuration_w;
						80:  
							DC_pstParameterAg24.p2C01_Scommand_r := DC_pstParameterAg24.p2C01_Scommand_w;
					END_CASE;	
				ELSE
					(* write bsError *)
					nCounterWrite := vnCounterWrite;
					vnCounterWrite := 0;
					vnWrState := 0;
					bsDone:=FALSE;
					bsBusy:=FALSE;
					bsError:=TRUE;
					nStatus := fbEplSDOWrite.status;
					nErrorInfo := fbEplSDOWrite.errorinfo;
					fbEplSDORead.enable := 0;
				END_IF;
			END_IF;	
	END_CASE;		
	
	CASE vnCopyState OF
		COPY_STATE_WAIT_RTRIG:
			IF vbOsrCopy AND (vnRdState = 0) AND (vnWrState = 0) AND (vnRdDataObjState = 0) AND (vnWrDataObjState = 0) THEN
				IF (bsParameterValid = TRUE) THEN	
					vnCounterCopy := 1;
					nCounterCopy := 1;
					bsDone:=FALSE;
					bsBusy:=TRUE;
					bsError:=FALSE;
					nStatus := 16#FFFF; (* bsBusy *)
					nErrorInfo := 0;
					vnCopyState := COPY_STATE_COPY_R_TO_W;
				ELSE
					bsBusy := 0;
					bsError := 1;
					bsDone := 0;
					nStatus := 50000; (* no data object loaded *)
					nErrorInfo := 0;
				END_IF;	
			END_IF;	
		COPY_STATE_COPY_R_TO_W:
			vnCounterCopy := vnCounterCopy + 1;
			IF (vnCounterCopy > 80) THEN
				vnCounterCopy := 0;
				nCounterCopy := 0;
				vnCopyState := COPY_STATE_WAIT_RTRIG;
				bsBusy := 0;
				bsError := 0;
				bsDone := 1;
				nStatus := 0; (* no bsError *)
				nErrorInfo := 0;
			ELSE
				CASE vnCounterCopy OF
					1:  
						DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w := DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_r;
					2:  
						DC_pstParameterAg24.p2222_GenMapParam_w := DC_pstParameterAg24.p2222_GenMapParam_r;
					3:  
						DC_pstParameterAg24.p2241_PeakCurrentLimit_w := DC_pstParameterAg24.p2241_PeakCurrentLimit_r;
					4:  
						DC_pstParameterAg24.p2242_PeakCurrentTime_w := DC_pstParameterAg24.p2242_PeakCurrentTime_r;
					5:  
						DC_pstParameterAg24.p2243_ContinuousCurrent_w := DC_pstParameterAg24.p2243_ContinuousCurrent_r;
					6:  
						DC_pstParameterAg24.p2301_Do1Functionality_w := DC_pstParameterAg24.p2301_Do1Functionality_r;
					7:  
						DC_pstParameterAg24.p2303_DoPolarity_w := DC_pstParameterAg24.p2303_DoPolarity_r;
					8:  
						DC_pstParameterAg24.p2401_Di1Functionality_w := DC_pstParameterAg24.p2401_Di1Functionality_r;
					9:  
						DC_pstParameterAg24.p2402_Di2Functionality_w := DC_pstParameterAg24.p2402_Di2Functionality_r;
					10:  
						DC_pstParameterAg24.p2403_Di3Functionality_w := DC_pstParameterAg24.p2403_Di3Functionality_r;
					11:  
						DC_pstParameterAg24.p2404_Di4Functionality_w := DC_pstParameterAg24.p2404_Di4Functionality_r;
					12:  
						DC_pstParameterAg24.p2406_DiPolarity_w := DC_pstParameterAg24.p2406_DiPolarity_r;
					13:  
						DC_pstParameterAg24.p2601_ControllerParameterP_w := DC_pstParameterAg24.p2601_ControllerParameterP_r;
					14:  
						DC_pstParameterAg24.p2602_ControllerParameterI_w := DC_pstParameterAg24.p2602_ControllerParameterI_r;
					15:  
						DC_pstParameterAg24.p2603_ControllerParameterD_w := DC_pstParameterAg24.p2603_ControllerParameterD_r;
					16:  
						DC_pstParameterAg24.p2604_APos_w := DC_pstParameterAg24.p2604_APos_r;
					17:  
						DC_pstParameterAg24.p2605_VPos_w := DC_pstParameterAg24.p2605_VPos_r;
					18:  
						DC_pstParameterAg24.p2606_DPos_w := DC_pstParameterAg24.p2606_DPos_r;
					19:  
						DC_pstParameterAg24.p2607_ARot_w := DC_pstParameterAg24.p2607_ARot_r;
					20:  
						DC_pstParameterAg24.p2608_AInch_w := DC_pstParameterAg24.p2608_AInch_r;
					21:  
						DC_pstParameterAg24.p2609_VInch_w := DC_pstParameterAg24.p2609_VInch_r;
					22:  
						DC_pstParameterAg24.p260A_PosWindow_w := DC_pstParameterAg24.p260A_PosWindow_r;
					23:  
						DC_pstParameterAg24.p260B_GearRatioNumerator_w := DC_pstParameterAg24.p260B_GearRatioNumerator_r;
					24:  
						DC_pstParameterAg24.p260C_GearRatioDenominator_w := DC_pstParameterAg24.p260C_GearRatioDenominator_r;
					25:  
						DC_pstParameterAg24.p260D_SpindlePitch_w := DC_pstParameterAg24.p260D_SpindlePitch_r;
					26:  
						DC_pstParameterAg24.p260E_CalibrationValue_w := DC_pstParameterAg24.p260E_CalibrationValue_r;
					27:  
						DC_pstParameterAg24.p260F_SoftwareLimit1_w := DC_pstParameterAg24.p260F_SoftwareLimit1_r;
					28:  
						DC_pstParameterAg24.p2610_SoftwareLimit2_w := DC_pstParameterAg24.p2610_SoftwareLimit2_r;
					29:  
						DC_pstParameterAg24.p2611_DeltaInch_w := DC_pstParameterAg24.p2611_DeltaInch_r;
					30:  
						DC_pstParameterAg24.p2612_SenseOfRotation_w := DC_pstParameterAg24.p2612_SenseOfRotation_r;
					31:  
						DC_pstParameterAg24.p2613_PosType_w := DC_pstParameterAg24.p2613_PosType_r;
					32:  
						DC_pstParameterAg24.p2614_OperatingMode_w := DC_pstParameterAg24.p2614_OperatingMode_r;
					33:  
						DC_pstParameterAg24.p2615_Inching2StopMode_w := DC_pstParameterAg24.p2615_Inching2StopMode_r;
					34:  
						DC_pstParameterAg24.p2616_InposMode_w := DC_pstParameterAg24.p2616_InposMode_r;
					35:  
						DC_pstParameterAg24.p2617_LoopLength_w := DC_pstParameterAg24.p2617_LoopLength_r;
					36:  
						DC_pstParameterAg24.p2618_ContouringErrorLimit_w := DC_pstParameterAg24.p2618_ContouringErrorLimit_r;
					37:  
						DC_pstParameterAg24.p261A_Inching2Offset_w := DC_pstParameterAg24.p261A_Inching2Offset_r;
					38:  
						DC_pstParameterAg24.p261B_Inching2AccelerationType_w := DC_pstParameterAg24.p261B_Inching2AccelerationType_r;
					39:  
						DC_pstParameterAg24.p261C_OffsetValue_w := DC_pstParameterAg24.p261C_OffsetValue_r;
					40:  
						DC_pstParameterAg24.p2701_DisplayDivisor_w := DC_pstParameterAg24.p2701_DisplayDivisor_r;
					41:  
						DC_pstParameterAg24.p2702_DisplayDivApplication_w := DC_pstParameterAg24.p2702_DisplayDivApplication_r;
					42:  
						DC_pstParameterAg24.p2703_DisplayOrientation_w := DC_pstParameterAg24.p2703_DisplayOrientation_r;
					43:  
						DC_pstParameterAg24.p2704_DecimalPlaces_w := DC_pstParameterAg24.p2704_DecimalPlaces_r;
					44:  
						DC_pstParameterAg24.p2705_DirectionIndicationFunc_w := DC_pstParameterAg24.p2705_DirectionIndicationFunc_r;
					45:  
						DC_pstParameterAg24.p2706_Display2ndLine_w := DC_pstParameterAg24.p2706_Display2ndLine_r;
					46:  
						DC_pstParameterAg24.p2707_KeyEnableTime_w := DC_pstParameterAg24.p2707_KeyEnableTime_r;
					47:  
						DC_pstParameterAg24.p2708_KeyFunctionEnable_w := DC_pstParameterAg24.p2708_KeyFunctionEnable_r;
					48:  
						DC_pstParameterAg24.p2709_PinChange_w := DC_pstParameterAg24.p2709_PinChange_r;
					49:  
						DC_pstParameterAg24.p2801_TalTrigger_w := DC_pstParameterAg24.p2801_TalTrigger_r;
					50:  
						DC_pstParameterAg24.p2802_TalDirection_w := DC_pstParameterAg24.p2802_TalDirection_r;
					51:  
						DC_pstParameterAg24.p2922_PcmPosition1_w := DC_pstParameterAg24.p2922_PcmPosition1_r;
					52:  
						DC_pstParameterAg24.p2923_PcmPosition2_w := DC_pstParameterAg24.p2923_PcmPosition2_r;
					53:  
						DC_pstParameterAg24.p2924_PcmPosition3_w := DC_pstParameterAg24.p2924_PcmPosition3_r;
					54:  
						DC_pstParameterAg24.p2925_PcmPosition4_w := DC_pstParameterAg24.p2925_PcmPosition4_r;
					55:  
						DC_pstParameterAg24.p2926_PcmPosition5_w := DC_pstParameterAg24.p2926_PcmPosition5_r;
					56:  
						DC_pstParameterAg24.p2927_PcmPosition6_w := DC_pstParameterAg24.p2927_PcmPosition6_r;
					57:  
						DC_pstParameterAg24.p2928_PcmPosition7_w := DC_pstParameterAg24.p2928_PcmPosition7_r;
					58:  
						DC_pstParameterAg24.p2942_PcmAcceleration1_w := DC_pstParameterAg24.p2942_PcmAcceleration1_r;
					59:  
						DC_pstParameterAg24.p2943_PcmAcceleration2_w := DC_pstParameterAg24.p2943_PcmAcceleration2_r;
					60:  
						DC_pstParameterAg24.p2944_PcmAcceleration3_w := DC_pstParameterAg24.p2944_PcmAcceleration3_r;
					61:  
						DC_pstParameterAg24.p2945_PcmAcceleration4_w := DC_pstParameterAg24.p2945_PcmAcceleration4_r;
					62:  
						DC_pstParameterAg24.p2946_PcmAcceleration5_w := DC_pstParameterAg24.p2946_PcmAcceleration5_r;
					63:  
						DC_pstParameterAg24.p2947_PcmAcceleration6_w := DC_pstParameterAg24.p2947_PcmAcceleration6_r;
					64:  
						DC_pstParameterAg24.p2948_PcmAcceleration7_w := DC_pstParameterAg24.p2948_PcmAcceleration7_r;
					65:  
						DC_pstParameterAg24.p2962_PcmVelocity1_w := DC_pstParameterAg24.p2962_PcmVelocity1_r;
					66:  
						DC_pstParameterAg24.p2963_PcmVelocity2_w := DC_pstParameterAg24.p2963_PcmVelocity2_r;
					67:  
						DC_pstParameterAg24.p2964_PcmVelocity3_w := DC_pstParameterAg24.p2964_PcmVelocity3_r;
					68:  
						DC_pstParameterAg24.p2965_PcmVelocity4_w := DC_pstParameterAg24.p2965_PcmVelocity4_r;
					69:  
						DC_pstParameterAg24.p2966_PcmVelocity5_w := DC_pstParameterAg24.p2966_PcmVelocity5_r;
					70:  
						DC_pstParameterAg24.p2967_PcmVelocity6_w := DC_pstParameterAg24.p2967_PcmVelocity6_r;
					71:  
						DC_pstParameterAg24.p2968_PcmVelocity7_w := DC_pstParameterAg24.p2968_PcmVelocity7_r;
					72:  
						DC_pstParameterAg24.p2982_PcmDeceleration1_w := DC_pstParameterAg24.p2982_PcmDeceleration1_r;
					73:  
						DC_pstParameterAg24.p2983_PcmDeceleration2_w := DC_pstParameterAg24.p2983_PcmDeceleration2_r;
					74:  
						DC_pstParameterAg24.p2984_PcmDeceleration3_w := DC_pstParameterAg24.p2984_PcmDeceleration3_r;
					75:  
						DC_pstParameterAg24.p2985_PcmDeceleration4_w := DC_pstParameterAg24.p2985_PcmDeceleration4_r;
					76:  
						DC_pstParameterAg24.p2986_PcmDeceleration5_w := DC_pstParameterAg24.p2986_PcmDeceleration5_r;
					77:  
						DC_pstParameterAg24.p2987_PcmDeceleration6_w := DC_pstParameterAg24.p2987_PcmDeceleration6_r;
					78:  
						DC_pstParameterAg24.p2988_PcmDeceleration7_w := DC_pstParameterAg24.p2988_PcmDeceleration7_r;
					79:  
						DC_pstParameterAg24.p2B21_Configuration_w := DC_pstParameterAg24.p2B21_Configuration_r;
					80:  
						DC_pstParameterAg24.p2C01_Scommand_w := DC_pstParameterAg24.p2C01_Scommand_r;
				END_CASE;
			END_IF;
			nCounterCopy := vnCounterCopy;
	END_CASE;
	
	CASE vnRdDataObjState OF
		DORD_STATE_WAIT_RTRIG: (* start condition *)
			IF vbOsrReadDataObj AND (vnRdState = 0) AND (vnWrState = 0) AND (vnCopyState = 0) AND (vnWrDataObjState = 0) THEN
				bsDone:=FALSE;
				bsBusy:=TRUE;
				bsError:=FALSE;
				nStatus := 16#FFFF; (* bsBusy *)
				nErrorInfo := 0;
				vnCounterLoad := 0;
				vnRdDataObjState := DORD_STATE_IDENTIFY_MODULE;
			END_IF;	
		DORD_STATE_IDENTIFY_MODULE: (* check if DataObj exists *)
			DatObjInfo_0(enable := TRUE, pName := ADR(DC_sModulename));
			IF DatObjInfo_0.status = 0 THEN
				(* exists, read *)
				vnRdDataObjState := DORD_STATE_LOAD_TO_STRUCT;
			ELSIF DatObjInfo_0.status = doERR_MODULNOTFOUND THEN
				(* don't exists, load default values *)
				vnRdDataObjState := DORD_STATE_LOAD_DEFAULTS;
			ELSE 
				(* bsError *)
				vnRdDataObjState := DORD_STATE_WAIT_RTRIG;
				bsDone:=FALSE;
				bsBusy:=FALSE;
				bsError:=TRUE;
				nStatus := DatObjInfo_0.status;
				nErrorInfo := 0;
			END_IF
		DORD_STATE_LOAD_DEFAULTS: (* load structure with default values *)
			vnCounterLoad := vnCounterLoad + 1;
			IF (vnCounterLoad > 80) THEN
				vnCounterLoad := 0;
				vnRdDataObjState := DORD_STATE_CREATE_MODULE;
			ELSE
				CASE vnCounterLoad OF
					1:  
						DC_pstParameterAg24.p2221_ServiceInterfaceBaudRate_w := 1;
					2:  
						DC_pstParameterAg24.p2222_GenMapParam_w := 0;
					3:  
						DC_pstParameterAg24.p2241_PeakCurrentLimit_w := 12000;
					4:  
						DC_pstParameterAg24.p2242_PeakCurrentTime_w := 40;
					5:  
						DC_pstParameterAg24.p2243_ContinuousCurrent_w := 7500;
					6:  
						DC_pstParameterAg24.p2301_Do1Functionality_w := 0;
					7:  
						DC_pstParameterAg24.p2303_DoPolarity_w := 0;
					8:  
						DC_pstParameterAg24.p2401_Di1Functionality_w := 0;
					9:  
						DC_pstParameterAg24.p2402_Di2Functionality_w := 0;
					10:  
						DC_pstParameterAg24.p2403_Di3Functionality_w := 0;
					11:  
						DC_pstParameterAg24.p2404_Di4Functionality_w := 0;
					12:  
						DC_pstParameterAg24.p2406_DiPolarity_w := 0;
					13:  
						DC_pstParameterAg24.p2601_ControllerParameterP_w := 300;
					14:  
						DC_pstParameterAg24.p2602_ControllerParameterI_w := 2;
					15:  
						DC_pstParameterAg24.p2603_ControllerParameterD_w := 0;
					16:  
						DC_pstParameterAg24.p2604_APos_w := 50;
					17:  
						DC_pstParameterAg24.p2605_VPos_w := 10;
					18:  
						DC_pstParameterAg24.p2606_DPos_w := 101;
					19:  
						DC_pstParameterAg24.p2607_ARot_w := 50;
					20:  
						DC_pstParameterAg24.p2608_AInch_w := 50;
					21:  
						DC_pstParameterAg24.p2609_VInch_w := 10;
					22:  
						DC_pstParameterAg24.p260A_PosWindow_w := 10;
					23:  
						DC_pstParameterAg24.p260B_GearRatioNumerator_w := 1;
					24:  
						DC_pstParameterAg24.p260C_GearRatioDenominator_w := 1;
					25:  
						DC_pstParameterAg24.p260D_SpindlePitch_w := 0;
					26:  
						DC_pstParameterAg24.p260E_CalibrationValue_w := 0;
					27:  
						DC_pstParameterAg24.p260F_SoftwareLimit1_w := 999999;
					28:  
						DC_pstParameterAg24.p2610_SoftwareLimit2_w := -199999;
					29:  
						DC_pstParameterAg24.p2611_DeltaInch_w := 1024;
					30:  
						DC_pstParameterAg24.p2612_SenseOfRotation_w := 0;
					31:  
						DC_pstParameterAg24.p2613_PosType_w := 0;
					32:  
						DC_pstParameterAg24.p2614_OperatingMode_w := 0;
					33:  
						DC_pstParameterAg24.p2615_Inching2StopMode_w := 0;
					34:  
						DC_pstParameterAg24.p2616_InposMode_w := 0;
					35:  
						DC_pstParameterAg24.p2617_LoopLength_w := 512;
					36:  
						DC_pstParameterAg24.p2618_ContouringErrorLimit_w := 1024;
					37:  
						DC_pstParameterAg24.p261A_Inching2Offset_w := 100;
					38:  
						DC_pstParameterAg24.p261B_Inching2AccelerationType_w := 0;
					39:  
						DC_pstParameterAg24.p261C_OffsetValue_w := 0;
					40:  
						DC_pstParameterAg24.p2701_DisplayDivisor_w := 0;
					41:  
						DC_pstParameterAg24.p2702_DisplayDivApplication_w := 0;
					42:  
						DC_pstParameterAg24.p2703_DisplayOrientation_w := 0;
					43:  
						DC_pstParameterAg24.p2704_DecimalPlaces_w := 0;
					44:  
						DC_pstParameterAg24.p2705_DirectionIndicationFunc_w := 0;
					45:  
						DC_pstParameterAg24.p2706_Display2ndLine_w := 0;
					46:  
						DC_pstParameterAg24.p2707_KeyEnableTime_w := 3;
					47:  
						DC_pstParameterAg24.p2708_KeyFunctionEnable_w := 0;
					48:  
						DC_pstParameterAg24.p2709_PinChange_w := 0;
					49:  
						DC_pstParameterAg24.p2801_TalTrigger_w := 0;
					50:  
						DC_pstParameterAg24.p2802_TalDirection_w := 0;
					51:  
						DC_pstParameterAg24.p2922_PcmPosition1_w := 0;
					52:  
						DC_pstParameterAg24.p2923_PcmPosition2_w := 0;
					53:  
						DC_pstParameterAg24.p2924_PcmPosition3_w := 0;
					54:  
						DC_pstParameterAg24.p2925_PcmPosition4_w := 0;
					55:  
						DC_pstParameterAg24.p2926_PcmPosition5_w := 0;
					56:  
						DC_pstParameterAg24.p2927_PcmPosition6_w := 0;
					57:  
						DC_pstParameterAg24.p2928_PcmPosition7_w := 0;
					58:  
						DC_pstParameterAg24.p2942_PcmAcceleration1_w := 50;
					59:  
						DC_pstParameterAg24.p2943_PcmAcceleration2_w := 50;
					60:  
						DC_pstParameterAg24.p2944_PcmAcceleration3_w := 50;
					61:  
						DC_pstParameterAg24.p2945_PcmAcceleration4_w := 50;
					62:  
						DC_pstParameterAg24.p2946_PcmAcceleration5_w := 50;
					63:  
						DC_pstParameterAg24.p2947_PcmAcceleration6_w := 50;
					64:  
						DC_pstParameterAg24.p2948_PcmAcceleration7_w := 50;
					65:  
						DC_pstParameterAg24.p2962_PcmVelocity1_w := 10;
					66:  
						DC_pstParameterAg24.p2963_PcmVelocity2_w := 10;
					67:  
						DC_pstParameterAg24.p2964_PcmVelocity3_w := 10;
					68:  
						DC_pstParameterAg24.p2965_PcmVelocity4_w := 10;
					69:  
						DC_pstParameterAg24.p2966_PcmVelocity5_w := 10;
					70:  
						DC_pstParameterAg24.p2967_PcmVelocity6_w := 10;
					71:  
						DC_pstParameterAg24.p2968_PcmVelocity7_w := 10;
					72:  
						DC_pstParameterAg24.p2982_PcmDeceleration1_w := 101;
					73:  
						DC_pstParameterAg24.p2983_PcmDeceleration2_w := 101;
					74:  
						DC_pstParameterAg24.p2984_PcmDeceleration3_w := 101;
					75:  
						DC_pstParameterAg24.p2985_PcmDeceleration4_w := 101;
					76:  
						DC_pstParameterAg24.p2986_PcmDeceleration5_w := 101;
					77:  
						DC_pstParameterAg24.p2987_PcmDeceleration6_w := 101;
					78:  
						DC_pstParameterAg24.p2988_PcmDeceleration7_w := 101;
					79:  
						DC_pstParameterAg24.p2B21_Configuration_w := 15;
					80:  
						DC_pstParameterAg24.p2C01_Scommand_w := 0;
				END_CASE;
			END_IF;	
		DORD_STATE_CREATE_MODULE: (* create DataObj *)
			(* DatObjCreate is asynchronous *)
			DatObjCreate_0(enable := TRUE, grp := 0, pName := ADR(DC_sModulename), len := SIZEOF(DC_pstParameterAg24), MemType := doUSRROM, Option := 0, pCpyData := ADR(DC_pstParameterAg24));
			IF DatObjCreate_0.status <> 16#FFFF THEN
				IF DatObjCreate_0.status = 0 THEN
					(* executed correctly *)
					vnRdDataObjState := DORD_STATE_SET_PARAMETER_VALID;
					nStatus := 0;
				ELSE
					(* bsError *)
					vnRdDataObjState := DORD_STATE_WAIT_RTRIG;
					bsDone:=FALSE;
					bsBusy:=FALSE;
					bsError:=TRUE;
					nStatus := DatObjCreate_0.status;
					nErrorInfo := 0;
				END_IF
			END_IF
		DORD_STATE_LOAD_TO_STRUCT: (* load DataObj to structure *)
			DatObjRead_0(enable := TRUE, ident := DatObjInfo_0.ident, Offset := 0, pDestination := ADR(DC_pstParameterAg24), len := DatObjInfo_0.len);
			IF DatObjRead_0.status = 0 THEN
				(* ready, set bsParameterValid TRUE *)
				nStatus := 0;
				vnRdDataObjState := DORD_STATE_SET_PARAMETER_VALID;
			ELSE
				(* bsError *)
				vnRdDataObjState := DORD_STATE_WAIT_RTRIG;
				bsDone:=FALSE;
				bsBusy:=FALSE;
				bsError:=TRUE;
				nStatus := DatObjRead_0.status;
				nErrorInfo := 0;
			END_IF 
		DORD_STATE_SET_PARAMETER_VALID: (* set bsParameterValid true *)
			bsParameterValid := TRUE;
			bsDone:=TRUE;
			bsBusy:=FALSE;
			bsError:=FALSE;
			nStatus := 0; (* no bsError *)
			nErrorInfo := 0;	
			vnRdDataObjState := DORD_STATE_WAIT_RTRIG;
	END_CASE;	
	
	CASE vnWrDataObjState OF
		DOWR_STATE_WAIT_RTRIG: (* start condition *)
			IF vbOsrWriteDataObj AND (vnRdState = 0) AND (vnWrState = 0) AND (vnCopyState = 0) AND (vnRdDataObjState = 0) THEN
				bsDone:=FALSE;
				bsBusy:=TRUE;
				bsError:=FALSE;
				nStatus := 16#FFFF; (* bsBusy *)
				nErrorInfo := 0;
				vnCounterLoad := 0;
				vnWrDataObjState := DOWR_STATE_IDENTIFY_MODULE;
			END_IF;
		DOWR_STATE_IDENTIFY_MODULE:
			DatObjInfo_0(enable := TRUE, pName := ADR(DC_sModulename));
			IF DatObjInfo_0.status = 0 THEN
				(* exists, delete *)
				vnWrDataObjState := DOWR_STATE_DELETE_MODULE;
			ELSIF DatObjInfo_0.status = doERR_MODULNOTFOUND THEN
				(* don't exists, generate *)
				vnWrDataObjState := DOWR_STATE_CREATE_MODULE;
			ELSE 
				(* bsError *)
				vnWrDataObjState := DOWR_STATE_WAIT_RTRIG;
				bsDone:=FALSE;
				bsBusy:=FALSE;
				bsError:=TRUE;
				nStatus := DatObjInfo_0.status;
				nErrorInfo := 0;
			END_IF
		DOWR_STATE_DELETE_MODULE:
			DatObjDelete_0.enable := TRUE;
			DatObjDelete_0.ident := DatObjInfo_0.ident;
			DatObjDelete_0();
			IF DatObjDelete_0.status <> 16#FFFF THEN
				IF DatObjDelete_0.status = 0 THEN
					(* ready *)
					vnWrDataObjState:= DOWR_STATE_CREATE_MODULE;
				ELSE
					(* bsError *)
					vnWrDataObjState := DOWR_STATE_WAIT_RTRIG;
					bsDone:=FALSE;
					bsBusy:=FALSE;
					bsError:=TRUE;
					nStatus := DatObjDelete_0.status;
					nErrorInfo := 0;
				END_IF
			END_IF
		DOWR_STATE_CREATE_MODULE:
			DatObjCreate_0(enable := TRUE, grp := 0, pName := ADR(DC_sModulename), len := SIZEOF(DC_pstParameterAg24), MemType := doUSRROM, Option := 0, pCpyData := ADR(DC_pstParameterAg24));
			IF DatObjCreate_0.status <> 16#FFFF THEN
				vnWrDataObjState:= DOWR_STATE_WAIT_RTRIG;
				IF DatObjCreate_0.status = 0 THEN
					(* ready *)
					bsDone:=TRUE;
					bsBusy:=FALSE;
					bsError:=FALSE;
					nStatus := 0; (* no bsError *)
					nErrorInfo := 0;
				ELSE
					(* bsError *)
					bsDone:=FALSE;
					bsBusy:=FALSE;
					bsError:=TRUE;
					nStatus := DatObjCreate_0.status;
					nErrorInfo := 0;
				END_IF
			END_IF
	END_CASE;	
	
	(* Status Word *)
	nStatusWord := DC_nStatusWord;
	
	bs00_Supply:= nStatusWord.0;
	bs01_ReadinessToTravel:= nStatusWord.1;
	bs02_UpperLimit:= nStatusWord.2;
	bs03_LowerLimit:= nStatusWord.3;
	bs04_ActuatorTravels:= nStatusWord.4;
	bs05_InPos:= nStatusWord.5;
	bs06_ActiveTravelJob:= nStatusWord.6;
	bs07_Error:= nStatusWord.7;
	bs08_OperationEnabled:= nStatusWord.8;
	bs09_SwitchLock:= nStatusWord.9;
	bs10_TravelJobAck:= nStatusWord.10;
	bs11:= nStatusWord.11;
	bs12_CurrentLimiting:= nStatusWord.12;
	bs13_LimitSwitch1:= nStatusWord.13;
	bs14_LimitSwitch2:= nStatusWord.14;
	bs15_CalAck:= nStatusWord.15;
	
	(* Actual Value *)
	nActualValue := DC_nActualValue;
	
	(* Generic Mapping Channel *)
	nGenMapCh := DC_nGenMapCh;
	
	(* Digital Inputs Status *)
	nDigitalInputsStatus := DC_nDigitalInputsState;
	
	bsDigitalInput1:= nDigitalInputsStatus.0;
	bsDigitalInput2:= nDigitalInputsStatus.1;
	bsDigitalInput3:= nDigitalInputsStatus.2;
	bsDigitalInput4:= nDigitalInputsStatus.3;

END_FUNCTION_BLOCK